==> sumus-6.3.3-sources.jar: io/intino/sumus/graph/dynamic/DynamicEntity.java <==
package io.intino.sumus.graph.dynamic;

import io.intino.sumus.graph.*;


public class DynamicEntity extends io.intino.tara.magritte.Layer {
	protected java.time.Instant created;
	protected boolean alive;

	protected io.intino.sumus.graph.Entity _entity;

	public DynamicEntity(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public java.time.Instant created() {
		return created;
	}

	public boolean alive() {
		return alive;
	}

	public DynamicEntity alive(boolean value) {
		this.alive = value;
		return (DynamicEntity) this;
	}

	public java.util.List<io.intino.sumus.graph.Entity> entityList() {
		return (java.util.List<io.intino.sumus.graph.Entity>) _entity.entityList();
	}

	public io.intino.sumus.graph.Entity entityList(int index) {
		return _entity.entityList().get(index);
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());

		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		map.put("created", new java.util.ArrayList(java.util.Collections.singletonList(this.created)));
		map.put("alive", new java.util.ArrayList(java.util.Collections.singletonList(this.alive)));
		return map;
	}

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("created")) this.created = io.intino.tara.magritte.loaders.InstantLoader.load(values, this).get(0);
		else if (name.equalsIgnoreCase("alive")) this.alive = io.intino.tara.magritte.loaders.BooleanLoader.load(values, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("created")) this.created = (java.time.Instant) values.get(0);
		else if (name.equalsIgnoreCase("alive")) this.alive = (java.lang.Boolean) values.get(0);
	}

	@Override
	protected void sync$(io.intino.tara.magritte.Layer layer) {
		super.sync$(layer);
	    if (layer instanceof io.intino.sumus.graph.Entity) _entity = (io.intino.sumus.graph.Entity) layer;

	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.sumus.graph.Entity entity() {
		    io.intino.sumus.graph.Entity newElement = core$().graph().concept(io.intino.sumus.graph.Entity.class).createNode(name, core$()).as(io.intino.sumus.graph.Entity.class);

		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void entity(java.util.function.Predicate<io.intino.sumus.graph.Entity> filter) {
			new java.util.ArrayList<>(entityList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}

==> sumus-7.2.1-sources.jar: io/intino/sumus/graph/dynamic/DynamicEntity.java <==
package io.intino.sumus.graph.dynamic;

import io.intino.sumus.graph.*;


public class DynamicEntity extends io.intino.tara.magritte.Layer {
	protected java.time.Instant created;
	protected boolean alive;

	protected io.intino.sumus.graph.Entity _entity;

	public DynamicEntity(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public java.time.Instant created() {
		return created;
	}

	public boolean alive() {
		return alive;
	}

	public DynamicEntity alive(boolean value) {
		this.alive = value;
		return (DynamicEntity) this;
	}

	public java.util.List<io.intino.sumus.graph.Entity> entityList() {
		return (java.util.List<io.intino.sumus.graph.Entity>) _entity.entityList();
	}

	public io.intino.sumus.graph.Entity entityList(int index) {
		return _entity.entityList().get(index);
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());

		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		map.put("created", new java.util.ArrayList(java.util.Collections.singletonList(this.created)));
		map.put("alive", new java.util.ArrayList(java.util.Collections.singletonList(this.alive)));
		return map;
	}

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("created")) this.created = io.intino.tara.magritte.loaders.InstantLoader.load(values, this).get(0);
		else if (name.equalsIgnoreCase("alive")) this.alive = io.intino.tara.magritte.loaders.BooleanLoader.load(values, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("created")) this.created = (java.time.Instant) values.get(0);
		else if (name.equalsIgnoreCase("alive")) this.alive = (java.lang.Boolean) values.get(0);
	}

	@Override
	protected void sync$(io.intino.tara.magritte.Layer layer) {
		super.sync$(layer);
	    if (layer instanceof io.intino.sumus.graph.Entity) _entity = (io.intino.sumus.graph.Entity) layer;

	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.sumus.graph.Entity entity() {
		    io.intino.sumus.graph.Entity newElement = core$().graph().concept(io.intino.sumus.graph.Entity.class).createNode(this.name, core$()).as(io.intino.sumus.graph.Entity.class);

		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void entity(java.util.function.Predicate<io.intino.sumus.graph.Entity> filter) {
			new java.util.ArrayList<>(entityList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}
